﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using System.Web;
using Microsoft.AspNet.SignalR;
using Newtonsoft.Json;

namespace SignalRDemo
{
    public class MyConnection : PersistentConnection
    {

        /// <summary>
        /// 建立新连接时调用
        /// </summary>
        /// <param name="request">当前连接的请求</param>
        /// <param name="connectionId">进行重新连接的客户端的 ID。</param>
        /// <returns>连接操作完成时将完成的 System.Threading.Tasks.Task。 </returns>
        protected override Task OnConnected(IRequest request, string connectionId)
        {
            return Connection.Send(connectionId, "Welcome!");
        }

        /// <summary>
        /// 从连接接收数据时调用
        /// </summary>
        /// <param name="request">当前连接的请求</param>
        /// <param name="connectionId"> 发送数据的连接的 ID。</param>
        /// <param name="data">发送到连接的负载。</param>
        /// <returns>接收操作完成时将完成的 System.Threading.Tasks.Task。</returns>
        protected override Task OnReceived(IRequest request, string connectionId, string data)
        {
            var mode = JsonConvert.DeserializeObject<MyChart>(data);
            if (mode.Action == "welcome")
            {
                this.Groups.Add(connectionId, mode.RoomName);

                //除了当前这个人，该房间的其他人都会受到welcom new user的消息。
                return this.Groups.Send(mode.RoomName, string.Format("欢迎新用户进入房间： {0}", mode.RoomName), connectionId);
            }
            else
            {
                //发送的消息，排除当前这个人
                return this.Groups.Send(mode.RoomName, string.Format("用户{0}说:{1}", connectionId, mode.Data), connectionId);
            }
        }
    }


    public class MyChart
    {
        public string RoomName { get; set; }
        public string Data { get; set; }
        public string Action { get; set; }

    }
}